# HOST_NAME = "http://127.0.0.1:8000/"
# HOST_NAME = "https://sb-api.logicplum.com/"
HOST_NAME = "https://staging.logicplum.com/"

PROJECT_CREATE = "api/v2/external/create-project"
MODEL_TRAIN = "api/v2/external/train"
MODEL_TRAIN_STATUS = "api/v2/external/train/status"
MODEL_SCORE = "api/v2/external/score"
